@@ -13,5 +13,13 @@ pref("app.normandy.enabled",               false);
    so corporations can easily turn it back on if there's demand for that */
 pref("permissions.manager.remote.enabled", false);
 pref("spellchecker.dictionary_path", "/usr/share/myspell");
+/* Force hardware accelerated rendering due to USE=hwaccel */
+pref("gfx.webrender.all",                     true);
+pref("layers.acceleration.force-enabled",     true);
+pref("layers.gpu-process.enabled",            true);
+pref("media.hardware-video-decoding.enabled", true);
+pref("webgl.force-enabled",                   true);
+pref("gfx.x11-egl.force-enabled", false);
+pref("media.gmp-gmpopenh264.autoupdate", false);
+pref("media.gmp-widevinecdm.autoupdate", false);
 sticky_pref("gfx.font_rendering.graphite.enabled", true);
-pref("browser.gnome-search-provider.enabled", true);
